==> haskell-colour-2.3.6-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colour
version:              2.3.6
visibility:           public
id:                   colour-2.3.6-E2uR4JnJZk43eyqNgJWgLM
key:                  colour-2.3.6-E2uR4JnJZk43eyqNgJWgLM
license:              MIT
maintainer:           Russell O'\''Connor <roconnor@theorem.ca>
author:               Russell O'\''Connor
homepage:             http://www.haskell.org/haskellwiki/Colour
synopsis:             A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.

category:             data, graphics
abi:                  be8de64ef7fa39f997dc6c30a91e9875
exposed:              True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear

hidden-modules:
    Data.Colour.Internal Data.Colour.Chan Data.Colour.RGB
    Data.Colour.Matrix Data.Colour.CIE.Chromaticity

import-dirs:          /usr/lib/ghc-9.0.1/site-local/colour-2.3.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/colour-2.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colour
hs-libraries:         HScolour-2.3.6-E2uR4JnJZk43eyqNgJWgLM
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html:         /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colour-2.3.6-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colour
version:              2.3.6
visibility:           public
id:                   colour-2.3.6-A2WfTrEvP6L95Bkq22KRLt
key:                  colour-2.3.6-A2WfTrEvP6L95Bkq22KRLt
license:              MIT
maintainer:           Russell O'\''Connor <roconnor@theorem.ca>
author:               Russell O'\''Connor
homepage:             http://www.haskell.org/haskellwiki/Colour
synopsis:             A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.

category:             data, graphics
abi:                  a1cc59f91b72926d2f64f98c8cb6931d
exposed:              True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear

hidden-modules:
    Data.Colour.Internal Data.Colour.Chan Data.Colour.RGB
    Data.Colour.Matrix Data.Colour.CIE.Chromaticity

import-dirs:          /usr/lib/ghc-9.0.1/site-local/colour-2.3.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/colour-2.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colour
hs-libraries:         HScolour-2.3.6-A2WfTrEvP6L95Bkq22KRLt
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html:         /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
